@@ -4,7 +4,7 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.18_11';
+  our $VERSION = '0.18_12';
 
   use Zydeco
     authority => 'cpan:SMONFF',
@@ -114,8 +114,6 @@ package Art::World {
           '', '' ),
         namespace => __PACKAGE__ . '::Model'
        );
-      say ref $dbh;
-      p $dbh;
       return $dbh;
     }
 
